@@ -171,7 +171,7 @@ pub struct PushHook {
     /// The username of the user who pushed.
     pub user_username: String,
     /// The email address of the user who pushed.
-    pub user_email: String,
+    pub user_email: Option<String>,
     /// The URL of the user's avatar.
     pub user_avatar: Option<String>,
     /// The ID of the project pushed to.
@@ -792,7 +792,8 @@ pub struct PipelineProjectAttrs {
     pub path_with_namespace: String,
     /// The default branch for the project.
     pub default_branch: Option<String>,
-    pub ci_config_path: String,
+    /// The path to the ci config file.
+    pub ci_config_path: Option<String>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
